@@ -15,6 +15,19 @@ using namespace google::protobuf;
 using namespace gpd;
 using namespace std;
 
+#if __cplusplus < 201103L
+namespace {
+    string to_string(int value) {
+        char buffer[30];
+
+        // only used for error handling, so it does not have to be performant
+        sprintf(buffer, "%d", value);
+
+        return buffer;
+    }
+}
+#endif
+
 namespace {
     void PerlLogHandler(LogLevel level, const char *filename, int line,
                         const std::string &message) {
@@ -64,7 +77,7 @@ bool SourceTreeDescriptorDatabaseWithFallback::FindFileByName(
         FileDescriptorProto* output) {
     // this will open the file twice, but I prefer that to copy more of
     // SourceTreeDescriptorDatabase implementation
-    io::ZeroCopyInputStream *input = source_tree->Open(filename);
+    google::protobuf::io::ZeroCopyInputStream *input = source_tree->Open(filename);
 
     if (input == NULL) {
         if (fallback_database->FindFileByName(filename, output)) {
